@@ -367,6 +367,16 @@ ftp_transfer(UrlResource *rsrc)
                         passive = 0;
         }
 
+        if (u->file) {
+                send_control(sock, "SIZE ", u->file, "\r\n", NULL);
+                line = get_line(rsrc, sock);
+                if (line && check_numeric("213", line)) {
+                        rsrc->outfile_size = atoi(line + 3);
+                } else {
+                        rsrc->outfile_size = 0;
+                }
+        }
+
         /* handle resume */
         if( rsrc->outfile_offset && (rsrc->options & OPT_RESUME) ) {
                 char numstring[BUFSIZE]; /* ugly hack */
@@ -385,17 +395,9 @@ ftp_transfer(UrlResource *rsrc)
                 safe_free(line);
         }
 
-        if( u->file ) {
-                send_control(sock, "SIZE ", u->file, "\r\n", NULL);
-                line = get_line(rsrc, sock);
-                if (line && check_numeric("213", line)) {
-                        rsrc->outfile_size = atoi(line + 3);
-                } else {
-                        rsrc->outfile_size = 0;
-                }
-
+        if (u->file)
                 send_control(sock, "RETR ", u->file, "\r\n", NULL);
-        } else
+        else
                 send_control(sock, "NLST\r\n", NULL);
 
         if( !((line = get_line(rsrc, sock)) &&
