@@ -4,17 +4,10 @@
 #define LLIST_H
 
 typedef struct _List 		List;
-typedef struct _ListNode 	ListNode;
-
-struct _ListNode {
-	struct _ListNode *next;
-	void *data;
-};
 
 struct _List {
-        int count;
-	ListNode *first_node;
-	ListNode *current_node;
+        void *data;
+        List *next;
 };
 
 
@@ -24,8 +17,7 @@ struct _List {
 #ifdef PROTOTYPES
 
 List *		list_new(void);
-List *		list_add_node(List *, ListNode *);
-ListNode *	list_node_new(void);
+List *		list_append(List *, void *);
 
 #endif /* PROTOTYPES */
 
